@@ -55,7 +55,7 @@ private slots:
 private:
 	QFont font;
 	bool flagShowAngleMeasure;
-	bool lineVisible;
+	LinearFader lineVisible;
 	LinearFader messageFader;
 	QTimer* messageTimer;
 	bool dragging;
@@ -69,9 +69,6 @@ private:
 	Vec3f lineColor;
 	QString angleText;
 	bool flagUseDmsFormat;
-	QPixmap* pxmapGlow;
-	QPixmap* pxmapOnIcon;
-	QPixmap* pxmapOffIcon;
 	StelButton* toolbarButton;
 
 	void calculateEnds(void);
