@@ -95,24 +95,28 @@ Oculars::Oculars() : selectedOcularIndex(-1), flagShowOculars(false), usageMessa
 {
 	flagShowOculars = false;
 	flagShowCrosshairs = false;
+	flagShowTelrad = false;
 	font.setPixelSize(14);
 	maxImageCircle = 0.0;
+	CCDs = QList<CCD *>();
 	oculars = QList<Ocular *>();
-	ready = true;
+	ready = false;
+	selectedCCDIndex = 0;
 	selectedOcularIndex = 0;
 	selectedTelescopeIndex = 0;
 	setObjectName("Oculars");
 	telescopes = QList<Telescope *>();
 	useMaxImageCircle = true;
 	visible = false;
+	ocularsTableModel = NULL;
+	telescopesTableModel = NULL;
+	ocularDialog = NULL;
 }
 
 Oculars::~Oculars()
 {
-	QSqlDatabase db = QSqlDatabase::database("oculars");
-	db.close();
-	QSqlDatabase::removeDatabase(QSqlDatabase::defaultConnection);
-
+	delete CCDsTableModel;
+	CCDsTableModel = NULL;
 	delete ocularsTableModel;
 	ocularsTableModel = NULL;
 	delete telescopesTableModel;
@@ -132,79 +136,48 @@ bool Oculars::configureGui(bool show)
 	if (show)
 	{
 		StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+		Q_ASSERT(gui);
 		gui->getGuiActions("actionShow_Ocular_Window")->setChecked(true);
 	}
-	
-	return true;
+
+	return ready;
 }
 
 //! Draw any parts on the screen which are for our module
 void Oculars::draw(StelCore* core)
 {
-	const StelProjectorP prj = core->getProjection(StelCore::FrameAltAz);
-	StelPainter painter(prj);
-	painter.setFont(font);
-
-	// Insure there is a selected ocular & telescope
-	if (selectedOcularIndex > oculars.count()) {
-		qWarning() << "Oculars: the selected ocular index of " << selectedOcularIndex << " is greate that the ocular count of "
-		<< oculars.count() << ". Module disable.";
-		ready = false;
+	if (flagShowTelrad) {
+		drawTelrad();
 	}
-	if (selectedTelescopeIndex > telescopes.count()) {
-		qWarning() << "Oculars: the selected telescope index of " << selectedTelescopeIndex << " is greate that the telescope count of "
-		<< telescopes.count() << ". Module disable.";
-		ready = false;
+	if (flagShowOculars){
+		// Insure there is a selected ocular & telescope
+		if (selectedCCDIndex > CCDs.count()) {
+			qWarning() << "Oculars: the selected sensor index of " << selectedCCDIndex << " is greater than the sensor count of "
+			<< CCDs.count() << ". Module disabled!";
+			ready = false;
+		}
+		if (selectedOcularIndex > oculars.count()) {
+			qWarning() << "Oculars: the selected ocular index of " << selectedOcularIndex << " is greater than the ocular count of "
+			<< oculars.count() << ". Module disabled!";
+			ready = false;
+		}
+		else if (selectedTelescopeIndex > telescopes.count()) {
+			qWarning() << "Oculars: the selected telescope index of " << selectedTelescopeIndex << " is greater than the telescope count of "
+			<< telescopes.count() << ". Module disabled!";
+			ready = false;
+		}
+		
+		if (ready) {
+			paintMask();
+			if (flagShowCrosshairs)  {
+				drawCrosshairs();
+			}
+			// Paint the information in the upper-right hand corner
+			paintText(core);
+		}
+		newInstrument = false; // Now that it's been drawn once
 	}
-
-	if (ready && flagShowOculars) {
-		paintMask();
-		if (flagShowCrosshairs)  {
-			drawCrosshairs();
-		}
-		Ocular *ocular = oculars[selectedOcularIndex];
-		Telescope *telescope = telescopes[selectedTelescopeIndex];
-		QString widthString = "MMMMMMMMMMMMMMMMMMM";
-		QString string1 = "Ocular #" + QVariant(selectedOcularIndex).toString();
-		if (ocular->getName() != QString(""))  {
-			string1.append(" : ").append(ocular->getName());
-		}
-		QString string2 = "Ocular aFOV: " + QVariant(ocular->getAppearentFOV()).toString() + QChar(0x00B0);
-		QString string4 = "Telescope #" + QVariant(selectedTelescopeIndex).toString();
-		if (telescope->getName() != QString(""))  {
-			string4.append(" : ").append(telescope->getName());
-		}
-		QString string5 = "Magnification: " + QVariant(((int)(ocular->getMagnification(telescope) * 10.0)) / 10.0).toString() + "x";
-		QString string6 = "Image Circle: " + QVariant(((int)(ocular->getExitCircle(telescope) * 10.0)) / 10.0).toString() + "mm";
-		QString string7 = "FOV: " + QVariant(((int)(ocular->getAcutalFOV(telescope) * 10000.00)) / 10000.0).toString() + QChar(0x00B0);
-
-		float insetFromRHS = painter.getFontMetrics().width(widthString);
-
-		StelProjector::StelProjectorParams projectorParams = core->getCurrentStelProjectorParams();
-		int xPosition = projectorParams.viewportXywh[2];
-		xPosition -= insetFromRHS;
-		int yPosition = projectorParams.viewportXywh[3];
-		yPosition -= 40;
-
-		painter.setColor(0.8, 0.48, 0.0, 1);
-		glDisable(GL_TEXTURE_2D);
-		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-		glEnable(GL_BLEND);
-
-		const int lineHeight = painter.getFontMetrics().height();
-		painter.drawText(xPosition, yPosition, string1);
-		yPosition-=lineHeight;
-		painter.drawText(xPosition, yPosition, string2);
-		yPosition-=lineHeight;
-		painter.drawText(xPosition, yPosition, string4);
-		yPosition-=lineHeight;
-		painter.drawText(xPosition, yPosition, string5);
-		yPosition-=lineHeight;
-		painter.drawText(xPosition, yPosition, string6);
-		yPosition-=lineHeight;
-		painter.drawText(xPosition, yPosition, string7);
-	}
-	newIntrument = false; // Now that it's been drawn once
+	
 }
 
 //! Determine which "layer" the plagin's drawing will happen on.
@@ -227,8 +200,8 @@ double Oculars::getCallOrder(StelModuleActionName actionName) const
 
 void Oculars::handleMouseClicks(class QMouseEvent* event)
 {
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
-	StelMovementMgr::StelMovementMgr *movementManager = core->getMovementMgr();
+	StelCore *core = StelApp::getInstance().getCore();
+	StelMovementMgr *movementManager = core->getMovementMgr();
 	if (StelApp::getInstance().getStelObjectMgr().getWasSelected()){
 		LabelMgr *labelManager = GETSTELMODULE(LabelMgr);
 
@@ -256,12 +229,6 @@ void Oculars::handleMouseClicks(class QMouseEvent* event)
 	event->setAccepted(false);
 }
 
-bool Oculars::handleMouseMoves(int x, int y, Qt::MouseButtons b)
-{
-	// Allow it to go up the stack
-	return false;
-}
-
 void Oculars::init()
 {
 	qDebug() << "Ocular plugin - press Command-o to toggle eyepiece view mode. Press ALT-o for configuration.";
@@ -269,9 +236,10 @@ void Oculars::init()
 	// Load settings from ocular.ini
 	validateIniFile();
 	if (initializeDB()) {
+		// assume all is well
 		ready = true;
-		ocularDialog = new OcularDialog(ocularsTableModel, telescopesTableModel);
-		initializeActions();
+		ocularDialog = new OcularDialog(CCDsTableModel, ocularsTableModel, telescopesTableModel);
+		initializeActivationActions();
 	}
 	try {
 		StelFileMgr::Flags flags = (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable);
@@ -282,18 +250,47 @@ void Oculars::init()
 	} catch (std::runtime_error& e) {
 		qWarning() << "WARNING: unable to locate ocular.ini file or create a default one for Ocular plugin: " << e.what();
 	}
+
+	//Load the module's custom style sheets
+	QFile styleSheetFile;
+	styleSheetFile.setFileName(":/ocular/normalStyle.css");
+	if(styleSheetFile.open(QFile::ReadOnly|QFile::Text))
+	{
+		normalStyleSheet = styleSheetFile.readAll();
+	}
+	styleSheetFile.close();
+	styleSheetFile.setFileName(":/ocular/nightStyle.css");
+	if(styleSheetFile.open(QFile::ReadOnly|QFile::Text))
+	{
+		nightStyleSheet = styleSheetFile.readAll();
+	}
+	styleSheetFile.close();
 }
 
-void Oculars::setStelStyle(const StelStyle& style)
+void Oculars::deinit()
 {
-	/*
-	if(dialog) {
-		dialog->setStyleSheet(telescopeManager->getModuleStyleSheet(style.confSectionName));
-	}
-	 */
+	QSqlDatabase db = QSqlDatabase::database("oculars");
+	db.close();
+	QSqlDatabase::removeDatabase(QSqlDatabase::defaultConnection);
+}
 
-	//Change the styles of all children, too
-	ocularDialog->setStelStyle(style);
+void Oculars::setStelStyle(const QString&)
+{
+	ocularDialog->updateStyle();
+}
+
+const StelStyle Oculars::getModuleStyleSheet(const StelStyle& style)
+{
+	StelStyle pluginStyle(style);
+	if (style.confSectionName == "color")
+	{
+		pluginStyle.qtStyleSheet.append(normalStyleSheet);
+	}
+	else
+	{
+		pluginStyle.qtStyleSheet.append(nightStyleSheet);
+	}
+	return pluginStyle;
 }
 
 /* ********************************************************************* */
@@ -327,10 +324,19 @@ void Oculars::determineMaxImageCircle()
 
 void Oculars::instrumentChanged()
 {
-	newIntrument = true;
+	newInstrument = true;
 	zoom(true);
 }
 
+void Oculars::loadCCDs()
+{
+	CCDs.clear();
+	int rowCount = CCDsTableModel->rowCount();
+	for (int row = 0; row < rowCount; row++) {
+		CCDs.append(new CCD(CCDsTableModel->record(row)));
+	}
+}
+
 void Oculars::loadOculars()
 {
 	oculars.clear();
@@ -338,11 +344,6 @@ void Oculars::loadOculars()
 	for (int row = 0; row < rowCount; row++) {
 		oculars.append(new Ocular(ocularsTableModel->record(row)));
 	}
-	if (oculars.size() == 0) {
-		ready = false;
-		qWarning() << "WARNING: no oculars found.  Feature will be disabled.";
-	}
-
 }
 
 void Oculars::loadTelescopes()
@@ -352,11 +353,6 @@ void Oculars::loadTelescopes()
 	for (int row = 0; row < rowCount; row++) {
 		telescopes.append(new Telescope(telescopesTableModel->record(row)));
 	}
-	if (telescopes.size() == 0) {
-		ready = false;
-		qWarning() << "WARNING: no telescopes found.  Feature will be disabled.";
-	}
-
 }
 
 void Oculars::setScaleImageCircle(bool state)
@@ -381,10 +377,15 @@ void Oculars::enableOcular(bool b)
 	}
 
 	if (b) {
+		// load data and determine if we're ready (if we have all required data)
 		loadDatabaseObjects();
 	}
+	if (!ready) {
+		// no, some data was missing. We already warned, done.
+		return;
+	}
 
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
+	StelCore *core = StelApp::getInstance().getCore();
 	LabelMgr* labelManager = GETSTELMODULE(LabelMgr);
 	// Toggle the plugin on & off.  To toggle on, we want to ensure there is a selected object.
 	if (!flagShowOculars && !StelApp::getInstance().getStelObjectMgr().getWasSelected()) {
@@ -414,6 +415,18 @@ void Oculars::enableOcular(bool b)
 			zoom(false);
 		}
 	}
+	if (flagShowOculars) {
+		initializeActions();
+	}
+}
+
+void Oculars::decrementCCDIndex()
+{
+	selectedCCDIndex--;
+	if (selectedCCDIndex == -1) {
+		selectedCCDIndex = CCDs.count() - 1;
+	}
+	emit(selectedCCDChanged());
 }
 
 void Oculars::decrementOcularIndex()
@@ -434,6 +447,15 @@ void Oculars::decrementTelescopeIndex()
 	emit(selectedTelescopeChanged());
 }
 
+void Oculars::incrementCCDIndex()
+{
+	selectedCCDIndex++;
+	if (selectedCCDIndex == CCDs.count()) {
+		selectedCCDIndex = 0;
+	}
+	emit(selectedCCDChanged());
+}
+
 void Oculars::incrementOcularIndex()
 {
 	selectedOcularIndex++;
@@ -457,6 +479,11 @@ void Oculars::toggleCrosshair()
 	flagShowCrosshairs = !flagShowCrosshairs;
 }
 
+void Oculars::toggleTelrad()
+{
+	flagShowTelrad = !flagShowTelrad;
+}
+
 /* ********************************************************************* */
 #if 0
 #pragma mark -
@@ -466,7 +493,7 @@ void Oculars::toggleCrosshair()
 void Oculars::drawCrosshairs()
 {
 	const StelProjectorP projector = StelApp::getInstance().getCore()->getProjection(StelCore::FrameEquinoxEqu);
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
+	StelCore *core = StelApp::getInstance().getCore();
 	StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
 	// Center of screen
 	Vec2i centerScreen(projector->getViewportPosX()+projector->getViewportWidth()/2,
@@ -486,7 +513,44 @@ void Oculars::drawCrosshairs()
 	painter.drawLine2d(centerScreen[0], centerScreen[1], centerScreen[0] - length, centerScreen[1]);
 }
 
-void Oculars::initializeActions()
+void Oculars::drawTelrad()
+{
+	if (!flagShowOculars) {
+		const StelProjectorP projector = StelApp::getInstance().getCore()->getProjection(StelCore::FrameEquinoxEqu);
+
+
+		StelCore *core = StelApp::getInstance().getCore();
+		StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
+
+		// StelPainter drawing
+		StelPainter painter(projector);
+		painter.setColor(0.77, 0.14, 0.16, 1.0);
+		Vec2i centerScreen(projector->getViewportPosX()+projector->getViewportWidth()/2,
+						   projector->getViewportPosY()+projector->getViewportHeight()/2);
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (0.5));
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (2.0));
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (4.0));
+
+//		// Direct drawing
+//		glDisable(GL_BLEND);
+//		glColor3f(0.f,0.f,0.f);
+//		glPushMatrix();
+//		glTranslated(params.viewportCenter[0], params.viewportCenter[1], 0.0);
+//		GLUquadricObj *quadric = gluNewQuadric();		
+//		// the gray circle
+//		glColor4f(0.77, 0.14, 0.16, 0.5);
+//		float radius = 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (0.5);
+//		gluDisk(quadric, radius - 1.0, radius, 256, 1);
+//		radius = 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (2.0);
+//		gluDisk(quadric, radius - 1.0, radius, 256, 1);
+//		radius = 0.5 * projector->getPixelPerRadAtCenter() * (M_PI/180) * (4.0);
+//		gluDisk(quadric, radius - 1.0, radius, 256, 1);
+//		gluDeleteQuadric(quadric);
+//		glPopMatrix();		
+	}
+}
+
+void Oculars::initializeActivationActions()
 {
 	QString group = "Oculars Plugin";
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
@@ -494,36 +558,17 @@ void Oculars::initializeActions()
 
 	gui->addGuiActions("actionShow_Ocular", N_("Enable ocular"), "Ctrl+O", "Plugin Key Bindings", true);
 	gui->getGuiActions("actionShow_Ocular")->setChecked(flagShowOculars);
-	gui->addGuiActions("actionShow_Ocular_Crosshair", N_("Toggle Crosshair"), "ALT+C", group, true);
-	gui->addGuiActions("actionShow_Ocular_Window", N_("Configuration Window"), "ALT+O", group, true);
-
-	gui->addGuiActions("actionShow_Ocular_increment", N_("Select next ocular"), "Ctrl+]", group, false);
-	gui->addGuiActions("actionShow_Ocular_decrement", N_("Select previous ocular"), "Ctrl+[", group, false);
-	gui->addGuiActions("actionShow_Telescope_increment", N_("Select next telescope"), "Shift+]", group, false);
-	gui->addGuiActions("actionShow_Telescope_decrement", N_("Select previous telescope"), "Shift+[", group, false);
-
 	connect(gui->getGuiActions("actionShow_Ocular"), SIGNAL(toggled(bool)), this, SLOT(enableOcular(bool)));
-	connect(gui->getGuiActions("actionShow_Ocular_Crosshair"), SIGNAL(toggled(bool)), this, SLOT(toggleCrosshair()));
+	gui->addGuiActions("actionShow_Ocular_Window", N_("Configuration Window"), "ALT+O", group, true);
 	connect(gui->getGuiActions("actionShow_Ocular_Window"), SIGNAL(toggled(bool)), ocularDialog, SLOT(setVisible(bool)));
 	connect(ocularDialog, SIGNAL(visibleChanged(bool)), gui->getGuiActions("actionShow_Ocular_Window"), SLOT(setChecked(bool)));
-
-	connect(gui->getGuiActions("actionShow_Ocular_increment"), SIGNAL(triggered()), this, SLOT(incrementOcularIndex()));
-	connect(gui->getGuiActions("actionShow_Ocular_decrement"), SIGNAL(triggered()), this, SLOT(decrementOcularIndex()));
-	connect(gui->getGuiActions("actionShow_Telescope_increment"), SIGNAL(triggered()), this, SLOT(incrementTelescopeIndex()));
-	connect(gui->getGuiActions("actionShow_Telescope_decrement"), SIGNAL(triggered()), this, SLOT(decrementTelescopeIndex()));
-	/*
-	 connect(telescopesTableModel, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), this, SLOT(dataChanged()));
-	 connect(telescopesTableModel, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SLOT(rowsInserted()));
-	 connect(telescopesTableModel, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SLOT(rowsRemoved()));
-	 */
-	connect(this, SIGNAL(selectedOcularChanged()), this, SLOT(instrumentChanged()));
-	connect(this, SIGNAL(selectedTelescopeChanged()), this, SLOT(instrumentChanged()));
-	connect(ocularDialog, SIGNAL(scaleImageCircleChanged(bool)), this, SLOT(setScaleImageCircle(bool)));
-
+	gui->addGuiActions("actionShow_Ocular_Telrad", N_("Display Telrad"), "Ctrl+B", group, true);
+	gui->getGuiActions("actionShow_Ocular_Telrad")->setChecked(flagShowTelrad);
+	connect(gui->getGuiActions("actionShow_Ocular_Telrad"), SIGNAL(toggled(bool)), this, SLOT(toggleTelrad()));
 
 	// Make a toolbar button
 	try {
-		pxmapGlow = new QPixmap(":/graphicGui/gui/glow32x32.png");
+		pxmapGlow = new QPixmap(":/graphicGui/glow32x32.png");
 		pxmapOnIcon = new QPixmap(":/ocular/bt_ocular_on.png");
 		pxmapOffIcon = new QPixmap(":/ocular/bt_ocular_off.png");
 
@@ -536,51 +581,99 @@ void Oculars::initializeActions()
 	} catch (std::runtime_error& e) {
 		qWarning() << "WARNING: unable create toolbar button for Oculars plugin: " << e.what();
 	}
-
 }
 
+void Oculars::initializeActions()
+{
+	static bool actions_initialized;
+	if (actions_initialized)
+		return;
+	actions_initialized = true;
+	QString group = "Oculars Plugin";
+	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+
+	Q_ASSERT(gui);
+	gui->addGuiActions("actionShow_Ocular_Crosshair", N_("Toggle Crosshair"), "ALT+C", group, true);
+
+	gui->addGuiActions("actionShow_CCD_increment", N_("Select next sensor"), "Shift+Ctrl+]", group, false);
+	gui->addGuiActions("actionShow_CCD_decrement", N_("Select previous sensor"), "Shift+Ctrl+[", group, false);
+	gui->addGuiActions("actionShow_Ocular_increment", N_("Select next ocular"), "Ctrl+]", group, false);
+	gui->addGuiActions("actionShow_Ocular_decrement", N_("Select previous ocular"), "Ctrl+[", group, false);
+	gui->addGuiActions("actionShow_Telescope_increment", N_("Select next telescope"), "Shift+]", group, false);
+	gui->addGuiActions("actionShow_Telescope_decrement", N_("Select previous telescope"), "Shift+[", group, false);
+
+	connect(gui->getGuiActions("actionShow_Ocular_Crosshair"), SIGNAL(toggled(bool)), this, SLOT(toggleCrosshair()));
+
+
+	connect(gui->getGuiActions("actionShow_CCD_increment"), SIGNAL(triggered()), this, SLOT(incrementCCDIndex()));
+	connect(gui->getGuiActions("actionShow_CCD_decrement"), SIGNAL(triggered()), this, SLOT(decrementCCDIndex()));
+	connect(gui->getGuiActions("actionShow_Ocular_increment"), SIGNAL(triggered()), this, SLOT(incrementOcularIndex()));
+	connect(gui->getGuiActions("actionShow_Ocular_decrement"), SIGNAL(triggered()), this, SLOT(decrementOcularIndex()));
+	connect(gui->getGuiActions("actionShow_Telescope_increment"), SIGNAL(triggered()), this, SLOT(incrementTelescopeIndex()));
+	connect(gui->getGuiActions("actionShow_Telescope_decrement"), SIGNAL(triggered()), this, SLOT(decrementTelescopeIndex()));
+	/*
+	 connect(telescopesTableModel, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)), this, SLOT(dataChanged()));
+	 connect(telescopesTableModel, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SLOT(rowsInserted()));
+	 connect(telescopesTableModel, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SLOT(rowsRemoved()));
+	 */
+	connect(this, SIGNAL(selectedCCDChanged()), this, SLOT(instrumentChanged()));
+	connect(this, SIGNAL(selectedOcularChanged()), this, SLOT(instrumentChanged()));
+	connect(this, SIGNAL(selectedTelescopeChanged()), this, SLOT(instrumentChanged()));
+	connect(ocularDialog, SIGNAL(scaleImageCircleChanged(bool)), this, SLOT(setScaleImageCircle(bool)));
+}
+
+// Return true if we're ready (could read all required data), false otherwise
 bool Oculars::initializeDB()
 {
-	bool result = false;
 	StelFileMgr::Flags flags = (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable);
 	QString dbPath = StelFileMgr::findFile("modules/Oculars/", flags);
 	QSqlDatabase db = QSqlDatabase::addDatabase("QSQLITE", "oculars");
 	db.setDatabaseName(dbPath + "oculars.sqlite");
 	if (db.open()) {
+#define EXEC(sql) if (!query.exec(sql)) { qDebug() << query.lastError(); return false;}
 		qDebug() << "Oculars opened the DB successfully.";
 		// See if the tables alreadt exist.
 		QStringList tableList = db.tables();
 		if (!tableList.contains("oculars")) {
 			QSqlQuery query = QSqlQuery(db);
-			query.exec("create table oculars (id INTEGER PRIMARY KEY, name VARCHAR, afov FLOAT, efl FLOAT, fieldStop FLOAT)");
-			query.exec("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('one', 43, 40, 0)");
-			query.exec("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('two', 82, 31, 0)");
-			query.exec("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('three', 52, 10.5, 0)");
-			query.exec("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('four', 52, 26, 0)");
-			query.exec("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('five', 82, 20, 0)");
-
+			EXEC("create table oculars (id INTEGER PRIMARY KEY, name VARCHAR, afov FLOAT, efl FLOAT, fieldStop FLOAT)");
+			EXEC("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('one', 43, 40, 0)");
+			EXEC("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('two', 82, 31, 0)");
+			EXEC("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('three', 52, 10.5, 0)");
+			EXEC("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('four', 52, 26, 0)");
+			EXEC("INSERT INTO oculars (name, afov, efl, fieldStop) VALUES ('five', 82, 20, 0)");
 		}
 		if (!tableList.contains("telescopes")) {
 			QSqlQuery query = QSqlQuery(db);
-			query.exec("create table telescopes (id INTEGER PRIMARY KEY, name VARCHAR, focalLength FLOAT, diameter FLOAT, vFlip VARCHAR, hFlip VARCHAR)");
-			query.exec("INSERT INTO telescopes (name, focalLength, diameter, vFlip, hFlip) VALUES ('C1400', 3190, 355.6, 'false', 'true')");
-			query.exec("INSERT INTO telescopes (name, focalLength, diameter, vFlip, hFlip) VALUES ('80EDF', 500, 80, 'false', 'false')");
+			EXEC("create table telescopes (id INTEGER PRIMARY KEY, name VARCHAR, focalLength FLOAT, diameter FLOAT, vFlip VARCHAR, hFlip VARCHAR)");
+			EXEC("INSERT INTO telescopes (name, focalLength, diameter, vFlip, hFlip) VALUES ('C1400', 3190, 355.6, 'false', 'true')");
+			EXEC("INSERT INTO telescopes (name, focalLength, diameter, vFlip, hFlip) VALUES ('80EDF', 500, 80, 'false', 'false')");
+		}
+		if (!tableList.contains("ccd")) {
+			QSqlQuery query = QSqlQuery(db);
+			EXEC("create table ccd (id INTEGER PRIMARY KEY, name VARCHAR, resolution_x INTEGER, resolution_y INTEGER, chip_width FLOAT, chip_height FLOAT, pixel_width FLOAT, pixel_height FLOAT)");
+			EXEC("INSERT INTO ccd (name, resolution_x, resolution_y, chip_width, chip_height, pixel_width, pixel_height) VALUES ('None', 0, 0, 0, 0, 0, 0)");
+			EXEC("INSERT INTO ccd (name, resolution_x, resolution_y, chip_width, chip_height, pixel_width, pixel_height) VALUES ('EOS 450D', 4272, 2848, 22.2, 14.8, 5.2, 5.2)");
 		}
 
 		// Set the table models
+		CCDsTableModel = new QSqlTableModel(0, db);
+		CCDsTableModel->setTable("ccd");
+		CCDsTableModel->select();
 		ocularsTableModel = new QSqlTableModel(0, db);
 		ocularsTableModel->setTable("oculars");
-		ocularsTableModel->select();
+		if (!ocularsTableModel->select())
+			return false;
 		telescopesTableModel = new QSqlTableModel(0, db);
 		telescopesTableModel->setTable("telescopes");
-		telescopesTableModel->select();
-
-		result = true;
+		if (!telescopesTableModel->select())
+			return false;
+#undef EXEC
+		return true;
 	} else {
-		qDebug() << "Oculars could not open its databse; disableing module.";
-		result = false;
+		qDebug() << "Oculars could not open its database; disabling module.";
 	}
-	return result;
+	return false;
 }
 
 void Oculars::interceptMovementKey(QKeyEvent* event)
@@ -588,12 +681,12 @@ void Oculars::interceptMovementKey(QKeyEvent* event)
 	// We onle care about the arrow keys.  This flag tracks that.
 	bool consumeEvent = false;
 
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
-	StelMovementMgr::StelMovementMgr *movementManager = core->getMovementMgr();
+	StelCore *core = StelApp::getInstance().getCore();
+	StelMovementMgr *movementManager = core->getMovementMgr();
 
 	if (event->type() == QEvent::KeyPress)
 	{
-		// Direction and zoom deplacements
+		// Direction and zoom replacements
 		switch (event->key())
 		{
 			case Qt::Key_Left:
@@ -684,16 +777,31 @@ void Oculars::interceptMovementKey(QKeyEvent* event)
 
 void Oculars::loadDatabaseObjects()
 {
+	loadCCDs();
 	loadOculars();
 	loadTelescopes();
 	if (useMaxImageCircle) {
 		determineMaxImageCircle();
 	}
+	// A telescope and one of [CCD|Ocular] must be defined for the plugin to be usable.
+	if (telescopes.size() == 0)
+	{
+		ready = false;
+		qWarning() << "WARNING: no telescopes found.  Ocular will be disabled.";
+	}
+	else if (oculars.size() == 0 && CCDs.size() == 0) {
+		ready = false;
+		qWarning() << "WARNING: no oculars or CCDs found.  Ocular will be disabled.";
+	}
+	else
+	{
+		ready = true;
+	}
 }
 
 void Oculars::paintMask()
 {
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
+	StelCore *core = StelApp::getInstance().getCore();
 	StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
 
 	glDisable(GL_BLEND);
@@ -716,9 +824,104 @@ void Oculars::paintMask()
 	glColor3f(0.15f,0.15f,0.15f);
 	gluDisk(quadric, inner - 1.0, inner, 256, 1);
 	gluDeleteQuadric(quadric);
+	// draw sensor rectangle
+	CCD *ccd = CCDs[selectedCCDIndex];
+	if (ccd) {
+		Ocular *ocular = oculars[selectedOcularIndex];
+		float CCDx = ccd->getActualFOVx(ocular);
+		float CCDy = ccd->getActualFOVy(ocular);
+		if (CCDx > 0.0 && CCDy > 0.0) {
+			glBegin(GL_LINE_LOOP);
+			glVertex2f(-CCDx, CCDy);
+			glVertex2f(CCDx, CCDy);
+			glVertex2f(CCDx, -CCDy);
+			glVertex2f(-CCDx, -CCDy);
+			glEnd();
+		}
+	}
 	glPopMatrix();
 }
 
+void Oculars::paintText(const StelCore* core)
+{
+	const StelProjectorP prj = core->getProjection(StelCore::FrameAltAz);
+	StelPainter painter(prj);	
+
+	// Get the current instruments
+	CCD *ccd = CCDs[selectedCCDIndex];
+	Ocular *ocular = oculars[selectedOcularIndex];
+	Telescope *telescope = telescopes[selectedTelescopeIndex];
+
+	// set up the color and the GL state
+	painter.setColor(0.8, 0.48, 0.0, 1);
+	glDisable(GL_TEXTURE_2D);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	glEnable(GL_BLEND);
+
+	// Get the X & Y positions, and the line height
+	painter.setFont(font);
+	QString widthString = "MMMMMMMMMMMMMMMMMMM";
+	float insetFromRHS = painter.getFontMetrics().width(widthString);
+	StelProjector::StelProjectorParams projectorParams = core->getCurrentStelProjectorParams();
+	int xPosition = projectorParams.viewportXywh[2];
+	xPosition -= insetFromRHS;
+	int yPosition = projectorParams.viewportXywh[3];
+	yPosition -= 40;
+	const int lineHeight = painter.getFontMetrics().height();
+	
+	// The CCD
+	QString ccdSensorLabel, ccdInfoLabel;
+	if (ccd && ccd->getChipWidth() > .0 && ccd->getChipHeight() > .0) {
+		ccdInfoLabel = "Dimension : " + QVariant(ccd->getChipWidth()).toString() + "x" + QVariant(ccd->getChipHeight()).toString() + " mm";
+		if (ccd->getName() != QString("")) {
+			ccdSensorLabel = "Sensor #" + QVariant(selectedCCDIndex).toString();
+			ccdSensorLabel.append(" : ").append(ccd->getName());
+		}
+	}
+	if (ccdSensorLabel != QString("")) {
+		painter.drawText(xPosition, yPosition, ccdSensorLabel);
+		yPosition-=lineHeight;
+		painter.drawText(xPosition, yPosition, ccdInfoLabel);
+		yPosition-=lineHeight;
+	}
+
+	// The Ocular
+	QString ocularNumberLabel = "Ocular #" + QVariant(selectedOcularIndex).toString();
+	if (ocular->getName() != QString(""))  {
+		ocularNumberLabel.append(" : ").append(ocular->getName());
+	}
+	painter.drawText(xPosition, yPosition, ocularNumberLabel);
+	yPosition-=lineHeight;
+
+	QString ocularFLLabel = "Ocular FL: " + QVariant(ocular->getEffectiveFocalLength()).toString() + QChar(0x00B0);
+	painter.drawText(xPosition, yPosition, ocularFLLabel);
+	yPosition-=lineHeight;
+
+	QString ocularFOVLabel = "Ocular aFOV: " + QVariant(ocular->getAppearentFOV()).toString() + QChar(0x00B0);
+	painter.drawText(xPosition, yPosition, ocularFOVLabel);
+	yPosition-=lineHeight;
+
+	// The telescope
+	QString telescopeNumberLabel = "Telescope #" + QVariant(selectedTelescopeIndex).toString();
+	if (telescope->getName() != QString(""))  {
+		telescopeNumberLabel.append(" : ").append(telescope->getName());
+	}
+	painter.drawText(xPosition, yPosition, telescopeNumberLabel);
+	yPosition-=lineHeight;
+
+	// General info
+	QString magnificationLabel = "Magnification: " + QVariant(((int)(ocular->getMagnification(telescope) * 10.0)) / 10.0).toString() + "x";
+	painter.drawText(xPosition, yPosition, magnificationLabel);
+	yPosition-=lineHeight;
+
+	QString imageCircleLabel = "Image Circle: " + QVariant(((int)(ocular->getExitCircle(telescope) * 10.0)) / 10.0).toString() + "mm";
+	painter.drawText(xPosition, yPosition, imageCircleLabel);
+	yPosition-=lineHeight;
+
+	QString fovLabel = "FOV: " + QVariant(((int)(ocular->getActualFOV(telescope) * 10000.00)) / 10000.0).toString() + QChar(0x00B0);
+	painter.drawText(xPosition, yPosition, fovLabel);
+}
+
 void Oculars::validateIniFile()
 {
 	// Insure the module directory exists
@@ -746,7 +949,7 @@ void Oculars::validateIniFile()
 
 		if (ocularsVersion < MIN_OCULARS_INI_VERSION) {
 			qWarning() << "Oculars::validateIniFile existing ini file version " << ocularsVersion
-						<< " to old to use; required version is " << MIN_OCULARS_INI_VERSION << ". Coping over new one.";
+						<< " too old to use; required version is " << MIN_OCULARS_INI_VERSION << ". Copying over new one.";
 			// delete last "old" file, if it exists
 			QFile deleteFile(ocularIniPath + ".old");
 			deleteFile.remove();
@@ -774,9 +977,9 @@ void Oculars::validateIniFile()
 
 void Oculars::unzoomOcular()
 {
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
-	StelMovementMgr::StelMovementMgr *movementManager = core->getMovementMgr();
-	GridLinesMgr::GridLinesMgr *gridManager = (GridLinesMgr *)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+	StelCore *core = StelApp::getInstance().getCore();
+	StelMovementMgr *movementManager = core->getMovementMgr();
+	GridLinesMgr *gridManager = (GridLinesMgr *)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 
 	gridManager->setFlagAzimuthalGrid(flagAzimuthalGrid);
 	gridManager->setFlagEquatorGrid(flagEquatorGrid);
@@ -798,10 +1001,9 @@ void Oculars::unzoomOcular()
 
 void Oculars::zoom(bool rezoom)
 {
-
 	if (flagShowOculars)  {
 		if (!rezoom)  {
-			GridLinesMgr::GridLinesMgr *gridManager = (GridLinesMgr *)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+			GridLinesMgr *gridManager = (GridLinesMgr *)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 			// Current state
 			flagAzimuthalGrid = gridManager->getFlagAzimuthalGrid();
 			flagEquatorGrid = gridManager->getFlagEquatorGrid();
@@ -821,9 +1023,9 @@ void Oculars::zoom(bool rezoom)
 
 void Oculars::zoomOcular()
 {
-	StelCore::StelCore *core = StelApp::getInstance().getCore();
-	StelMovementMgr::StelMovementMgr *movementManager = core->getMovementMgr();
-	GridLinesMgr::GridLinesMgr *gridManager =
+	StelCore *core = StelApp::getInstance().getCore();
+	StelMovementMgr *movementManager = core->getMovementMgr();
+	GridLinesMgr *gridManager =
 		(GridLinesMgr *)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 
 	gridManager->setFlagAzimuthalGrid(false);
@@ -832,14 +1034,16 @@ void Oculars::zoomOcular()
 	gridManager->setFlagEquatorLine(false);
 	gridManager->setFlagEclipticLine(false);
 	gridManager->setFlagMeridianLine(false);
+	
 	movementManager->setFlagTracking(true);
 	movementManager->setFlagEnableZoomKeys(false);
 	movementManager->setFlagEnableMouseNavigation(false);
+	
 	// We won't always have a selected object
 	if (StelApp::getInstance().getStelObjectMgr().getWasSelected()) {
 		movementManager->
 			moveToJ2000(StelApp::getInstance().getStelObjectMgr().getSelectedObject()[0]->getEquinoxEquatorialPos(core->getNavigator()),
-						0.5,
+						0.0,
 						1);
 	}
 
@@ -850,9 +1054,9 @@ void Oculars::zoomOcular()
 	core->setFlipHorz(telescope->isHFlipped());
 	core->setFlipVert(telescope->isVFlipped());
 
-	double actualFOV = ocular->getAcutalFOV(telescope);
-	// See if the mask was scaled
-	if (maxImageCircle > 0.0 && ocular->getExitCircle(telescope) > 0.0) {
+	double actualFOV = ocular->getActualFOV(telescope);
+	// See if the mask was scaled; if so, correct the actualFOV.
+	if (useMaxImageCircle && ocular->getExitCircle(telescope) > 0.0) {
 		actualFOV = maxImageCircle * actualFOV / ocular->getExitCircle(telescope);
 	}
 	movementManager->zoomTo(actualFOV, 0.0);
