@@ -30,11 +30,13 @@ struct EdgeVertex
 {
 	EdgeVertex() : edgeFlag(false) {;}
 	EdgeVertex(bool b) : edgeFlag(b) {;}
-	EdgeVertex(Vec3d v, bool b) : vertex(v), edgeFlag(b) {;}
+	EdgeVertex(const Vec3d& v, bool b) : vertex(v), edgeFlag(b) {;}
 	Vec3d vertex;
 	bool edgeFlag;
 };
 
+Q_DECLARE_TYPEINFO(EdgeVertex, Q_PRIMITIVE_TYPE);
+
 QDataStream& operator<<(QDataStream& out, const EdgeVertex&);
 QDataStream& operator>>(QDataStream& in, EdgeVertex&);
 
