@@ -205,6 +205,12 @@ void StelMovementMgr::handleKeys(QKeyEvent* event)
 				if (event->modifiers().testFlag(Qt::ControlModifier))
 					setDragTimeMode(true);
 				break;
+#ifdef BUILD_FOR_MAEMO
+			case Qt::Key_F8:
+				zoomIn(true); break;
+			case Qt::Key_F7:
+				zoomOut(true); break;
+#endif
 			default:
 				return;
 		}
@@ -235,6 +241,12 @@ void StelMovementMgr::handleKeys(QKeyEvent* event)
 			case Qt::Key_Control:
 				setDragTimeMode(false);
 				break;
+#ifdef BUILD_FOR_MAEMO
+			case Qt::Key_F8:
+				zoomIn(false); break;
+			case Qt::Key_F7:
+				zoomOut(false); break;
+#endif
 			default:
 				return;
 		}
