@@ -51,9 +51,9 @@ public:
 	virtual void init();
 
 	//! Update time-dependent things (does nothing).
-	virtual void update(double deltaTime) {;}
+	virtual void update(double) {;}
 	//! Implement required draw function.  Does nothing.
-	virtual void draw(StelCore* acore) {;}
+	virtual void draw(StelCore*) {;}
 	//! Handle keyboard events.
 	virtual void handleKeys(QKeyEvent* event);
 	//! Handle mouse movement events.
@@ -80,10 +80,13 @@ public:
 
 	//! Return the current up view vector.
 	Vec3d getViewUpVectorJ2000() const;
+	void setViewUpVectorJ2000(const Vec3d& up);
 
 	void setMovementSpeedFactor(float s) {movementsSpeedFactor=s;}
 	float getMovementSpeedFactor() const {return movementsSpeedFactor;}
 
+	void setDragTriggerDistance(float d) {dragTriggerDistance=d;}
+
 public slots:
 	//! Toggle current mount mode between equatorial and altazimuthal
 	void toggleMountMode() {if (getMountMode()==MountAltAzimuthal) setMountMode(MountEquinoxEquatorial); else setMountMode(MountAltAzimuthal);}
@@ -194,6 +197,9 @@ public slots:
 	//! Get current mount type defining the reference frame in which head movements occur.
 	MountMode getMountMode(void) const {return mountMode;}
 
+	void setDragTimeMode(bool b) {dragTimeMode=b;}
+	bool getDragTimeMode() const {return dragTimeMode;}
+
 private:
 	Vec3d j2000ToMountFrame(const Vec3d& v) const;
 	Vec3d mountFrameToJ2000(const Vec3d& v) const;
@@ -266,6 +272,14 @@ private:
 	bool isDragging, hasDragged;
 	int previousX, previousY;
 
+	// Contains the last N real time / JD times pairs associated with the last N mouse move events
+	QList<QPair<double, double> > timeDragHistory;
+	void addTimeDragPoint();
+	float beforeTimeDragTimeRate;
+
+	// Time mouse control
+	bool dragTimeMode;
+
 	//! @internal
 	//! Store data for auto-zoom.
 	struct AutoZoom
@@ -290,6 +304,10 @@ private:
 	Vec3d viewDirectionJ2000;
 	// Viewing direction in the mount reference frame.
 	Vec3d viewDirectionMountFrame;
+
+	Vec3d upVectorMountFrame;
+
+	float dragTriggerDistance;
 };
 
 #endif // _STELMOVEMENTMGR_HPP_
