@@ -51,12 +51,30 @@ public:
 		rootNode->processAll(func);
 	}
 
+	//! Remove all the elements in the container.
 	void clear()
 	{
 		rootNode->clear();
 	}
 
+	//! Return the total number of elements in the container.
+	unsigned int count()
+	{
+		CountFunc func;
+		processAll<CountFunc>(func);
+		return func.nb;
+	}
+
 private:
+	struct CountFunc
+	{
+		CountFunc() : nb(0) {;}
+		void operator()(const StelRegionObjectP&)
+		{
+			++nb;
+		}
+		unsigned int nb;
+	};
 
 	//! The elements stored in the container.
 	struct NodeElem
@@ -184,7 +202,7 @@ private:
 						const QVector<NodeElem> nodeElems = node.elements;
 						node.elements.clear();
 						// Re-insert the elements
-						for (QVector<NodeElem>::ConstIterator iter = nodeElems.begin();iter != nodeElems.end(); ++iter)
+						for (QVector<NodeElem>::ConstIterator iter = nodeElems.constBegin();iter != nodeElems.constEnd(); ++iter)
 						{
 							insert(node, *iter, level);
 						}
