@@ -27,6 +27,8 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QSettings>
 #include <QTextDocument>
+#include "StelModuleMgr.hpp"
+#include "StelObjectMgr.hpp"
 
 InfoPanel::InfoPanel(QGraphicsItem* parent) : QGraphicsTextItem("", parent)
 {
@@ -44,6 +46,9 @@ InfoPanel::InfoPanel(QGraphicsItem* parent) : QGraphicsTextItem("", parent)
 		qWarning() << "config.ini option gui/selected_object_info is invalid, using \"all\"";
 		infoTextFilters = StelObject::InfoStringGroup(StelObject::AllInfo);
 	}
+#ifdef BUILD_FOR_MAEMO
+	setFont(QFont("SmallSystemFont"));
+#endif
 }
 
 void InfoPanel::setTextFromObjects(const QList<StelObjectP>& selected)
@@ -61,6 +66,12 @@ void InfoPanel::setTextFromObjects(const QList<StelObjectP>& selected)
 	}
 }
 
+void InfoPanel::mousePressEvent(QGraphicsSceneMouseEvent* event)
+{
+  GETSTELMODULE(StelObjectMgr)->unSelect();
+  event->accept();
+}
+
 SkyGui::SkyGui(QGraphicsItem * parent): QGraphicsWidget(parent), stelGui(NULL)
 {
 	setObjectName("StelSkyGui");
