@@ -162,8 +162,8 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	group = N_("Movement and Selection");
 	addGuiActions("actionGoto_Selected_Object", N_("Center on selected object"), "Space", group, false, false);
 	addGuiActions("actionSet_Tracking", N_("Track object"), "T", group, true, false);
-	addGuiActions("actionZoom_In_Auto", N_("Zoom in on selected object"), "/", group, false, false);
-	addGuiActions("actionZoom_Out_Auto", N_("Zoom out"), "\\", group, false, false);
+	addGuiActions("actionZoom_In_Auto", N_("Zoom in on selected object"), "Ctrl+V", group, false, false);
+	addGuiActions("actionZoom_Out_Auto", N_("Zoom out"), "Ctrl+B", group, false, false);
 	addGuiActions("actionSet_Home_Planet_To_Selected", N_("Set home planet to selected planet"), "Ctrl+G", group, false, false);
 
 	group = N_("Miscellaneous");
