@@ -329,11 +329,17 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent, const QPixmap& pixLeft, cons
 
 	QColor color = QColor::fromRgbF(1,1,1,1);
 	setColor(color);
+#ifdef BUILD_FOR_MAEMO
+	QFont font("SmallSystemFont");
 
-	datetime->font().setPixelSize(12);
-	location->font().setPixelSize(12);
-	fov->font().setPixelSize(12);
-	fps->font().setPixelSize(12);
+#else
+	QFont font = QApplication::font();
+	font.setPixelSize(12)
+#endif
+	datetime->setFont(font);
+	location->setFont(font);
+	fov->setFont(font);
+	fps->setFont(font);
 
 	flagShowTime = true;
 	flagShowLocation = true;
