@@ -1,22 +1,22 @@
 /*
  * Stellarium
  * Copyright (C) 2008 Fabien Chereau
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
- 
+
 #ifndef _VIEWDIALOG_HPP_
 #define _VIEWDIALOG_HPP_
 
@@ -53,8 +53,14 @@ private slots:
 	//! Update the widget to make sure it is synchrone if a value was changed programmatically
 	//! This function should be called repeatidly with e.g. a timer
 	void updateFromProgram();
+
+	void populateSkyLayersList();
+	void skyLayersSelectionChanged(const QString&);
+	void skyLayersEnabledChanged(int);
+
+	void changePage(QListWidgetItem *current, QListWidgetItem *previous);
 private:
-	void updateSkyCultureText();	
+	void updateSkyCultureText();
 };
 
 #endif // _VIEWDIALOG_HPP_
